@@ -18,9 +18,6 @@
 #' @aliases pkg_download_result
 NULL
 
-#' @importFrom prettyunits pretty_bytes
-#' @importFrom cli ansi_hide_cursor ansi_show_cursor
-
 pkgplan_download_resolution <- function(self, private) {
   if (is.null(private$resolution)) self$resolve()
   if (private$dirty) {
@@ -30,8 +27,8 @@ pkgplan_download_resolution <- function(self, private) {
     ))
   }
   on.exit(private$done_progress_bar(), add = TRUE)
-  on.exit(ansi_show_cursor(), add = TRUE)
-  ansi_hide_cursor()
+  on.exit(cli::ansi_show_cursor(), add = TRUE)
+  cli::ansi_hide_cursor()
   synchronise(self$async_download_resolution())
 }
 
@@ -63,8 +60,8 @@ pkgplan_download_solution <- function(self, private) {
     ))
   }
   on.exit(private$done_progress_bar(), add = TRUE)
-  on.exit(ansi_show_cursor(), add = TRUE)
-  ansi_hide_cursor()
+  on.exit(cli::ansi_show_cursor(), add = TRUE)
+  cli::ansi_hide_cursor()
   synchronise(self$async_download_solution())
 }
 
@@ -93,8 +90,7 @@ pkgplan_stop_for_solution_download_error <- function(self, private) {
       which(bad),
       function(i) {
         urls <- format_items(dl$sources[[i]])
-        glue("Failed to download {dl$package[i]} \\
-              from {urls}.")
+        sprintf("Failed to download %s from %s.", dl$package[i], urls)
       }
     )
     msg <- paste(msgs, collapse = "\n")
@@ -112,8 +108,7 @@ pkgplan_stop_for_resolution_download_error <- function(self, private) {
       which(bad),
       function(i) {
         urls <- format_items(dl$sources[[i]])
-        glue("Failed to download {dl$package[i]} \\
-              from {urls}.")
+        sprintf("Failed to download %s from %s.", dl$package[i], urls)
       }
     )
     msg <- paste(msgs, collapse = "\n")
@@ -243,19 +238,37 @@ download_ping_if_no_sha <- function(resolution, target, config, cache,
   resolution; target; config; cache; on_progress
   mkdirp(dirname(target))
 
+  # If the cache is ignored, then we download it, always
   if (is_true_param(resolution$params[[1]], "nocache")) {
-    ## If the cache is ignored, then we just download it and put it
-    ## at the right place
-    download_one_of(
-      resolution$sources[[1]], target, on_progress = on_progress
-    )$
+    return(
+      download_one_of(
+        resolution$sources[[1]], target, on_progress = on_progress
+      )$
       then(function() "Got")
+    )
+  }
 
-  } else  if (! "sha256" %in% names(resolution) || is.na(resolution$sha256)) {
+  # If we wanted to _install_ a source package, then look for a
+  # locally built binary in the cache
+  rver <- config$get("r-versions")
+  if (resolution$platform == "source" && config$get("goal") == "install" &&
+      !is_true_param(resolution$params[[1]], "source") && length(rver) == 1) {
+    ## Try to find a binary in the cache
+    bin <- cache$package$copy_to(
+      target, package = resolution$package, version = resolution$version,
+      platform = current_r_platform(), built = TRUE, rversion = rver
+    )
+    if (nrow(bin)) {
+      return(async_constant("Had"))
+    }
+  }
+
+  if (! "sha256" %in% names(resolution) || is.na(resolution$sha256)) {
+    ## Otherwise we need to ping or download a package
     ## If we don't know the hash of the CRAN package, then just download
     ## it. This happens if there is some discrepancy between the package
     ## data and the metadata.
-    cache$package$async_copy_or_add(
+    cache$package$async_update_or_add(
       target, resolution$sources[[1]], path = resolution$target,
       package = resolution$package, version = resolution$version,
       platform = resolution$platform, on_progress = on_progress,
