@@ -33,7 +33,8 @@ res_make_empty_df <- local({
         extra    = list(),              # any extra data (e.g. GitHub sha)
         dep_types= list(),
         params   = list(),
-        sysreqs  = character()
+        sysreqs  = character(),
+        os_type  = character()
       )
     }
     data
@@ -68,9 +69,10 @@ res_df_defaults <- local({
         metadata = list(list()),
         mirror   = NA_character_,
         extra    = list(list()),
-        dep_types= list(list()),
+        dep_types= list("default"),
         params   = list(character()),
-        sysreqs  = NA_character_
+        sysreqs  = NA_character_,
+        os_type  = NA_character_
       )
     }
     data
@@ -114,8 +116,24 @@ res_one_row_df <- function(l) {
   assert_that(is.list(l) && all_named(l))
   samp <- res_make_empty_df()[names(l)]
   bad <- vlapply(samp, is.list) & !vlapply(l, is.list)
+  # If col is isn't a list col, but is supposed to be.
+  bad_len <- vlapply(samp, is.list) & !vlapply(l, function(x) length(x) == 1)
+  # If col is supposed to be a list, but isn't length one.
+  bad <- bad | bad_len
   l[bad] <- lapply(l[bad], list)
-  as_data_frame(l)
+  out <- as_data_frame(l)
+  assert_that(nrow(out) == 1)
+  out
+}
+
+res_list_to_df <- function(reslist) {
+  unk <- unlist(lapply(reslist, "[[", "unknown_deps"))
+  df <- res_make_empty_df()
+  for (res in reslist) {
+    df <- res_add_df_entries(df, remove_entry(res, "unknown_deps"))
+  }
+  attr(df, "unknown_deps") <- unk
+  df
 }
 
 res_add_defaults <- function(df) {
