@@ -1,8 +1,3 @@
-
-#' @importFrom crayon italic bold cyan silver bgRed white green
-#'   strip_style
-#' @importFrom cli tree symbol
-
 pkgplan_draw_solution_tree <- function(self, private, pkgs, annotate) {
 
   assert_that(is.null(pkgs) || is_character(pkgs))
@@ -27,14 +22,14 @@ pkgplan_draw_solution_tree <- function(self, private, pkgs, annotate) {
   data$deps <- lapply(data$deps, intersect, data$package)
 
   ann_version <- function() {
-    v <- silver(sol$version)
+    v <- cli::col_silver(sol$version)
     upd <- sol$lib_status == "update"
     if (any(upd)) {
-      v[upd] <- green(paste(sol$old_version[upd], "->", sol$version[upd]))
+      v[upd] <- cli::col_green(paste(sol$old_version[upd], "->", sol$version[upd]))
     }
     nupd <- sol$lib_status == "no-update"
     if (any(nupd)) {
-      v[nupd] <- green(paste(sol$version[nupd], "<", sol$new_version[nupd]))
+      v[nupd] <- cli::col_green(paste(sol$version[nupd], "<", sol$new_version[nupd]))
     }
     v
   }
@@ -46,7 +41,8 @@ pkgplan_draw_solution_tree <- function(self, private, pkgs, annotate) {
   )
   data$trimmed <- data$label
   data$label <- paste(data$label, ann_version())
-  data$label[sol$directpkg] <- italic(bold(cyan(data$label[sol$directpkg])))
+  data$label[sol$directpkg] <-
+    cli::style_italic(cli::style_bold(cli::col_cyan(data$label[sol$directpkg])))
 
   if (annotate) {
     builder <- emoji("builder")
@@ -59,30 +55,28 @@ pkgplan_draw_solution_tree <- function(self, private, pkgs, annotate) {
 
   trees <- unlist(lapply(
     pkgs,
-    function(p) c(tree(data, root = p, trim = TRUE), "")
+    function(p) c(cli::tree(data, root = p, trim = TRUE), "")
   ))
 
   if (annotate && any(unlist(ann))) {
     key <- paste0(
-      if (any(ann$new))     paste(" |", green(emoji("sparkles")), "new"),
-      if (any(ann$upd))     paste(" |", green(emoji("rocket")), "update"),
-      if (any(ann$noupd))   paste(" |", green(emoji("hand")), "outdated"),
-      if (any(ann$dl))      paste(" |", green(emoji("dl")), "download"),
-      if (any(ann$build))   paste(" |", green(builder), "build"),
-      if (any(ann$compile)) paste(" |", green(emoji("wrench")), "compile")
+      if (any(ann$new))     paste(" |", cli::col_green(emoji("sparkles")), "new"),
+      if (any(ann$upd))     paste(" |", cli::col_green(emoji("rocket")), "update"),
+      if (any(ann$noupd))   paste(" |", cli::col_green(emoji("hand")), "outdated"),
+      if (any(ann$dl))      paste(" |", cli::col_green(emoji("dl")), "download"),
+      if (any(ann$build))   paste(" |", cli::col_green(builder), "build"),
+      if (any(ann$compile)) paste(" |", cli::col_green(emoji("wrench")), "compile")
     )
     key <- paste0("Key: ", sub("^ [|]", "", key))
     trees <- c(trees, key)
   }
 
-  class(trees) <- c("tree", "character")
+  class(trees) <- c("cli_tree", "tree", "character")
   trees
 }
 
-#' @importFrom cli is_utf8_output
-
 has_emoji <- function() {
-  if (!is_utf8_output()) return(FALSE)
+  if (!cli::is_utf8_output()) return(FALSE)
   if (isTRUE(opt <- getOption("pkg.emoji"))) return(TRUE)
   if (identical(opt, FALSE)) return(FALSE)
   if (Sys.info()[["sysname"]] != "Darwin") return(FALSE)
@@ -104,11 +98,9 @@ get_tree_annotation <- function(sol) {
   ann
 }
 
-#' @importFrom crayon green
-
 annotate_tree <- function(sol, ann, builder = NULL) {
   builder <- builder %||% emoji("builder")
-  green(paste0(
+  cli::col_green(paste0(
     ifelse(ann$new, emoji("sparkles"), ""),
     ifelse(ann$upd, emoji("rocket"), ""),
     ifelse(ann$noupd, emoji("hand"), ""),
@@ -118,12 +110,9 @@ annotate_tree <- function(sol, ann, builder = NULL) {
   ))
 }
 
-#' @importFrom crayon silver
-#' @importFrom prettyunits pretty_bytes
-
 format_file_size <- function(x) {
-  bts <- str_trim(pretty_bytes(x))
-  silver(
+  bts <- str_trim(format_bytes$pretty_bytes(x))
+  cli::col_silver(
     ifelse(is.na(x), "(unknown size)", paste0("(", bts, ")"))
   )
 }
@@ -168,7 +157,7 @@ emo_builder <- function(n = 1) {
     "\U1F477\U1F3FF\u200D\u2642\uFE0F"
   )
 
-  rstudio_type <- rstudio$detect()$type
+  rstudio_type <- rstudio_detect()$type
   if (rstudio_type == "rstudio_terminal") {
     ppl <- base
   } else if (rstudio_type == "rstudio_console") {
