@@ -1,8 +1,5 @@
 
 test_that("hard example, because easch package has many candidates", {
-
-  skip_on_cran()
-  skip_if_offline()
   skip("unfinished")
 
   lib <- test_temp_dir()
